@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -975,12 +975,12 @@ class ModuleDocument(object):
                         paramList.append([paramName, "", []])
                     lastItem = paramList[-1][2]
                 elif desc.startswith("@type"):
+                    parts = desc.split(None, 1)
                     if lastTag not in ["@param", "@keyparam"]:
                         raise TagError(
                             "{0} line must be preceded by a parameter line\n"
                             .format(parts[0]))
                     inTagSection = True
-                    parts = desc.split(None, 1)
                     lastTag = parts[0]
                     if len(parts) < 2:
                         raise TagError(
@@ -1012,8 +1012,12 @@ class ModuleDocument(object):
                     returns = [parts[1]]
                     lastItem = returns
                 elif desc.startswith("@rtype"):
-                    inTagSection = True
                     parts = desc.split(None, 1)
+                    if lastTag not in ["@return", "@ireturn"]:
+                        raise TagError(
+                            "{0} line must be preceded by a return line\n"
+                            .format(parts[0]))
+                    inTagSection = True
                     lastTag = parts[0]
                     if len(parts) < 2:
                         raise TagError(
