@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,19 +9,20 @@ Module implementing a widget to select a symbol in various formats.
 
 from __future__ import unicode_literals
 
-import sys
-import unicodedata
 try:
-    # Py3
-    import html.entities as html_entities
-except (ImportError):
     # Py2
     str = unicode                               # __IGNORE_WARNING__
     chr = unichr                                # __IGNORE_WARNING__
     import htmlentitydefs as html_entities      # __IGNORE_WARNING__
+except (NameError, ImportError):
+    # Py3
+    import html.entities as html_entities
+
+import sys
+import unicodedata
 
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QAbstractTableModel, \
-    QModelIndex, Qt, qVersion, QItemSelectionModel
+    QModelIndex, Qt, qVersion, QItemSelectionModel, QLocale
 from PyQt5.QtGui import QColor
 from PyQt5.QtWidgets import QWidget, QHeaderView, QAbstractItemView
 
@@ -43,6 +44,8 @@ class SymbolsModel(QAbstractTableModel):
         """
         super(SymbolsModel, self).__init__(parent)
         
+        self.__locale = QLocale()
+        
         self.__headerData = [
             self.tr("Code"),
             self.tr("Char"),
@@ -362,7 +365,7 @@ class SymbolsModel(QAbstractTableModel):
         if role == Qt.DisplayRole:
             col = index.column()
             if col == 0:
-                return str(id)
+                return self.__locale.toString(id)
             elif col == 1:
                 return chr(id)
             elif col == 2:
@@ -469,6 +472,15 @@ class SymbolsModel(QAbstractTableModel):
         """
         return unicodedata.category(str(char)) in ["Pc", "Pd", "Ps", "Pe",
                                                    "Pi", "Pf", "Po"]
+    
+    def getLocale(self):
+        """
+        Public method to get the used locale.
+        
+        @return used locale
+        @rtype QLocale
+        """
+        return self.__locale
 
 
 class SymbolsWidget(QWidget, Ui_SymbolsWidget):
@@ -558,6 +570,7 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         self.symbolsTable.setUpdatesEnabled(False)
         self.__model.selectTable(index)
         self.symbolsTable.setUpdatesEnabled(True)
+        self.symbolsTable.resizeColumnsToContents()
         
         first, last = self.__model.getTableBoundaries(index)
         self.symbolSpinBox.setMinimum(first)
@@ -573,5 +586,5 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         @param previous previous current index (QModelIndex)
         """
         Preferences.Prefs.settings.setValue("Symbols/Top", current.row())
-        self.symbolSpinBox.setValue(int(
-            self.__model.data(self.__model.index(current.row(), 0))))
+        self.symbolSpinBox.setValue(self.__model.getLocale().toInt(
+            self.__model.data(self.__model.index(current.row(), 0)))[0])
